Tests whether a date is after another date.
Errors if one of the values cannot be parsed as a date.
Takes an optional inclusive argument defaulting to false to make this test be >= instead of >.
Tests whether a date is before another date.
Errors if one of the values cannot be parsed as a date.
Takes an optional inclusive argument defaulting to false to make this test be <= instead of <.